@@ -5,7 +5,7 @@
 #  Vestibulum commodo. Ut rhoncus gravida arcu.
 
 __author__ = "CountChangye <121116728@qq.com>"
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 
 class string(str):
@@ -34,9 +34,17 @@ class string(str):
     def decompose(self, index):
         return self.character_set[index - 1]
 
+    # 判断某个字符在字符串中出现了多少次
+    def judgment_times(self, target_character: str):
+        return sum(
+            single_character == target_character
+            for single_character in self.character_set
+        )
+
 
 if __name__ == "__main__":
     s = string("Hello")
     x = s.add(", world")
     print(type(x))
     print(s.decompose(5))
+    print(s.judgment_times('l'))
